# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import HeaderStr
from ....core import get_namespace as get_services_namespace
from ....core import run_request
from ....core import run_request_async
from ....core import same_doc_as

from ..models import DtoPlatformAccountClosureClientRequest
from ..models import DtoPlatformAccountClosureClientResponse
from ..models import DtoPlatformAccountClosureClientsResponse
from ..models import DtoPlatformAccountClosureMockRequest
from ..models import DtoXboxBPCertValidationRequest
from ..models import DtoXboxBPCertValidationResponse
from ..models import ResponseError

from ..operations.platform_account_closure_client import (
    AdminDeletePlatformAccountClosureClient,
)
from ..operations.platform_account_closure_client import (
    AdminGetPlatformAccountClosureClient,
)
from ..operations.platform_account_closure_client import (
    AdminGetPlatformAccountClosureClients,
)
from ..operations.platform_account_closure_client import (
    AdminMockPlatformAccountClosureData,
)
from ..operations.platform_account_closure_client import (
    AdminUpdatePlatformAccountClosureClient,
)
from ..operations.platform_account_closure_client import AdminValidateXboxBPCertFile


@same_doc_as(AdminDeletePlatformAccountClosureClient)
def admin_delete_platform_account_closure_client(
    platform: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Delete Platform Account Closure Client (AdminDeletePlatformAccountClosureClient)

    Delete platform account closure client.
    The namespace should be **publisher or studio namespace**
    -------
    Platform:
    - steamnetwork
    - xbox
    - psn

    Properties:
        url: /gdpr/admin/namespaces/{namespace}/platforms/{platform}/closure/client

        method: DELETE

        tags: ["Platform Account Closure Client"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        platform: (platform) REQUIRED str in path

    Responses:
        204: No Content - (No Content)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)

        404: Not Found - ResponseError (Not Found)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = AdminDeletePlatformAccountClosureClient.create(
        platform=platform,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminDeletePlatformAccountClosureClient)
async def admin_delete_platform_account_closure_client_async(
    platform: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Delete Platform Account Closure Client (AdminDeletePlatformAccountClosureClient)

    Delete platform account closure client.
    The namespace should be **publisher or studio namespace**
    -------
    Platform:
    - steamnetwork
    - xbox
    - psn

    Properties:
        url: /gdpr/admin/namespaces/{namespace}/platforms/{platform}/closure/client

        method: DELETE

        tags: ["Platform Account Closure Client"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        platform: (platform) REQUIRED str in path

    Responses:
        204: No Content - (No Content)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)

        404: Not Found - ResponseError (Not Found)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = AdminDeletePlatformAccountClosureClient.create(
        platform=platform,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(AdminGetPlatformAccountClosureClient)
def admin_get_platform_account_closure_client(
    platform: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get Platform Account Closure Config (AdminGetPlatformAccountClosureClient)

    Get platform account closure config.
    The namespace should be **publisher or studio namespace**
    ----------
    Platform:
    - steamnetwork
    - xbox
    - psn
    Scope: account

    Properties:
        url: /gdpr/admin/namespaces/{namespace}/platforms/{platform}/closure/client

        method: GET

        tags: ["Platform Account Closure Client"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        platform: (platform) REQUIRED str in path

    Responses:
        200: OK - DtoPlatformAccountClosureClientResponse (OK)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)

        404: Not Found - ResponseError (Not Found)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = AdminGetPlatformAccountClosureClient.create(
        platform=platform,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminGetPlatformAccountClosureClient)
async def admin_get_platform_account_closure_client_async(
    platform: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get Platform Account Closure Config (AdminGetPlatformAccountClosureClient)

    Get platform account closure config.
    The namespace should be **publisher or studio namespace**
    ----------
    Platform:
    - steamnetwork
    - xbox
    - psn
    Scope: account

    Properties:
        url: /gdpr/admin/namespaces/{namespace}/platforms/{platform}/closure/client

        method: GET

        tags: ["Platform Account Closure Client"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        platform: (platform) REQUIRED str in path

    Responses:
        200: OK - DtoPlatformAccountClosureClientResponse (OK)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)

        404: Not Found - ResponseError (Not Found)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = AdminGetPlatformAccountClosureClient.create(
        platform=platform,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(AdminGetPlatformAccountClosureClients)
def admin_get_platform_account_closure_clients(
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get Platform Account Closure Configs (AdminGetPlatformAccountClosureClients)

    Get platform account closure configs.
    ------
    Platform:
    - steamnetwork
    - xbox
    - psn
    Scope: account

    Properties:
        url: /gdpr/admin/namespaces/{namespace}/platforms/closure/clients

        method: GET

        tags: ["Platform Account Closure Client"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - DtoPlatformAccountClosureClientsResponse (OK)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)

        404: Not Found - ResponseError (Not Found)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = AdminGetPlatformAccountClosureClients.create(
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminGetPlatformAccountClosureClients)
async def admin_get_platform_account_closure_clients_async(
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get Platform Account Closure Configs (AdminGetPlatformAccountClosureClients)

    Get platform account closure configs.
    ------
    Platform:
    - steamnetwork
    - xbox
    - psn
    Scope: account

    Properties:
        url: /gdpr/admin/namespaces/{namespace}/platforms/closure/clients

        method: GET

        tags: ["Platform Account Closure Client"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - DtoPlatformAccountClosureClientsResponse (OK)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)

        404: Not Found - ResponseError (Not Found)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = AdminGetPlatformAccountClosureClients.create(
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(AdminMockPlatformAccountClosureData)
def admin_mock_platform_account_closure_data(
    body: DtoPlatformAccountClosureMockRequest,
    platform: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Mock Platform Account Closure Data (AdminMockPlatformAccountClosureData)

    Mock platform account closure data.
    -----
    **This is only for testing**
    Platform:
    - steamnetwork
    - xbox
    - psn
    Scope: account

    Properties:
        url: /gdpr/admin/namespaces/{namespace}/platforms/{platform}/closure/mock

        method: POST

        tags: ["Platform Account Closure Client"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED DtoPlatformAccountClosureMockRequest in body

        namespace: (namespace) REQUIRED str in path

        platform: (platform) REQUIRED str in path

    Responses:
        204: No Content - (No Content)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = AdminMockPlatformAccountClosureData.create(
        body=body,
        platform=platform,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminMockPlatformAccountClosureData)
async def admin_mock_platform_account_closure_data_async(
    body: DtoPlatformAccountClosureMockRequest,
    platform: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Mock Platform Account Closure Data (AdminMockPlatformAccountClosureData)

    Mock platform account closure data.
    -----
    **This is only for testing**
    Platform:
    - steamnetwork
    - xbox
    - psn
    Scope: account

    Properties:
        url: /gdpr/admin/namespaces/{namespace}/platforms/{platform}/closure/mock

        method: POST

        tags: ["Platform Account Closure Client"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED DtoPlatformAccountClosureMockRequest in body

        namespace: (namespace) REQUIRED str in path

        platform: (platform) REQUIRED str in path

    Responses:
        204: No Content - (No Content)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = AdminMockPlatformAccountClosureData.create(
        body=body,
        platform=platform,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(AdminUpdatePlatformAccountClosureClient)
def admin_update_platform_account_closure_client(
    body: DtoPlatformAccountClosureClientRequest,
    platform: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Update Platform Account Closure Client (AdminUpdatePlatformAccountClosureClient)

    Update platform account closure client.
    The namespace should be the **publisher or studio namespace**.
    ------
    Platform:
    - steamnetwork
    - xbox
    - psn
    Scope: account

    Properties:
        url: /gdpr/admin/namespaces/{namespace}/platforms/{platform}/closure/client

        method: POST

        tags: ["Platform Account Closure Client"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED DtoPlatformAccountClosureClientRequest in body

        namespace: (namespace) REQUIRED str in path

        platform: (platform) REQUIRED str in path

    Responses:
        204: No Content - (No Content)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = AdminUpdatePlatformAccountClosureClient.create(
        body=body,
        platform=platform,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminUpdatePlatformAccountClosureClient)
async def admin_update_platform_account_closure_client_async(
    body: DtoPlatformAccountClosureClientRequest,
    platform: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Update Platform Account Closure Client (AdminUpdatePlatformAccountClosureClient)

    Update platform account closure client.
    The namespace should be the **publisher or studio namespace**.
    ------
    Platform:
    - steamnetwork
    - xbox
    - psn
    Scope: account

    Properties:
        url: /gdpr/admin/namespaces/{namespace}/platforms/{platform}/closure/client

        method: POST

        tags: ["Platform Account Closure Client"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED DtoPlatformAccountClosureClientRequest in body

        namespace: (namespace) REQUIRED str in path

        platform: (platform) REQUIRED str in path

    Responses:
        204: No Content - (No Content)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = AdminUpdatePlatformAccountClosureClient.create(
        body=body,
        platform=platform,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(AdminValidateXboxBPCertFile)
def admin_validate_xbox_bp_cert_file(
    body: DtoXboxBPCertValidationRequest,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Validate Xbox BP cert file (AdminValidateXboxBPCertFile)

    Check xbox BP cert file whether it's expired and return expiration date

    Properties:
        url: /gdpr/admin/namespaces/{namespace}/platforms/xbox/closure/cert/validation

        method: POST

        tags: ["Platform Account Closure Client"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED DtoXboxBPCertValidationRequest in body

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - DtoXboxBPCertValidationResponse (OK)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)

        404: Not Found - ResponseError (Not Found)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = AdminValidateXboxBPCertFile.create(
        body=body,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminValidateXboxBPCertFile)
async def admin_validate_xbox_bp_cert_file_async(
    body: DtoXboxBPCertValidationRequest,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Validate Xbox BP cert file (AdminValidateXboxBPCertFile)

    Check xbox BP cert file whether it's expired and return expiration date

    Properties:
        url: /gdpr/admin/namespaces/{namespace}/platforms/xbox/closure/cert/validation

        method: POST

        tags: ["Platform Account Closure Client"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED DtoXboxBPCertValidationRequest in body

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - DtoXboxBPCertValidationResponse (OK)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)

        404: Not Found - ResponseError (Not Found)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = AdminValidateXboxBPCertFile.create(
        body=body,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# AccelByte Gaming Services Inventory Service Early Access

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import Model


class ApimodelsIntegrationConfigurationReq(Model):
    """Apimodels integration configuration req (apimodels.IntegrationConfigurationReq)

    Properties:
        service_name: (serviceName) REQUIRED str

        target_inventory_code: (targetInventoryCode) REQUIRED str

        map_item_type: (mapItemType) OPTIONAL List[str]
    """

    # region fields

    service_name: str  # REQUIRED
    target_inventory_code: str  # REQUIRED
    map_item_type: List[str]  # OPTIONAL

    # endregion fields

    # region with_x methods

    def with_service_name(self, value: str) -> ApimodelsIntegrationConfigurationReq:
        self.service_name = value
        return self

    def with_target_inventory_code(
        self, value: str
    ) -> ApimodelsIntegrationConfigurationReq:
        self.target_inventory_code = value
        return self

    def with_map_item_type(
        self, value: List[str]
    ) -> ApimodelsIntegrationConfigurationReq:
        self.map_item_type = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "service_name"):
            result["serviceName"] = str(self.service_name)
        elif include_empty:
            result["serviceName"] = ""
        if hasattr(self, "target_inventory_code"):
            result["targetInventoryCode"] = str(self.target_inventory_code)
        elif include_empty:
            result["targetInventoryCode"] = ""
        if hasattr(self, "map_item_type"):
            result["mapItemType"] = [str(i0) for i0 in self.map_item_type]
        elif include_empty:
            result["mapItemType"] = []
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls,
        service_name: str,
        target_inventory_code: str,
        map_item_type: Optional[List[str]] = None,
        **kwargs,
    ) -> ApimodelsIntegrationConfigurationReq:
        instance = cls()
        instance.service_name = service_name
        instance.target_inventory_code = target_inventory_code
        if map_item_type is not None:
            instance.map_item_type = map_item_type
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> ApimodelsIntegrationConfigurationReq:
        instance = cls()
        if not dict_:
            return instance
        if "serviceName" in dict_ and dict_["serviceName"] is not None:
            instance.service_name = str(dict_["serviceName"])
        elif include_empty:
            instance.service_name = ""
        if "targetInventoryCode" in dict_ and dict_["targetInventoryCode"] is not None:
            instance.target_inventory_code = str(dict_["targetInventoryCode"])
        elif include_empty:
            instance.target_inventory_code = ""
        if "mapItemType" in dict_ and dict_["mapItemType"] is not None:
            instance.map_item_type = [str(i0) for i0 in dict_["mapItemType"]]
        elif include_empty:
            instance.map_item_type = []
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, ApimodelsIntegrationConfigurationReq]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[ApimodelsIntegrationConfigurationReq]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[
        ApimodelsIntegrationConfigurationReq,
        List[ApimodelsIntegrationConfigurationReq],
        Dict[Any, ApimodelsIntegrationConfigurationReq],
    ]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "serviceName": "service_name",
            "targetInventoryCode": "target_inventory_code",
            "mapItemType": "map_item_type",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "serviceName": True,
            "targetInventoryCode": True,
            "mapItemType": False,
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import HeaderStr
from ....core import get_namespace as get_services_namespace
from ....core import run_request
from ....core import run_request_async
from ....core import same_doc_as

from ..models import IamErrorResponse
from ..models import ModelListScheduleByGoalResponse
from ..models import ModelListSchedulesResponse
from ..models import ResponseError

from ..operations.schedules import AdminListSchedules
from ..operations.schedules import AdminListSchedulesByGoal
from ..operations.schedules import PublicListSchedules
from ..operations.schedules import PublicListSchedulesByGoal


@same_doc_as(AdminListSchedules)
def admin_list_schedules(
    challenge_code: str,
    date_time: Optional[str] = None,
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    user_id: Optional[str] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get Challenge's schedules (adminListSchedules)

      * Required permission: ADMIN:NAMESPACE:{namespace}:CHALLENGE [READ]

    List schedules of given challenge for specific user. To query schedules prior to specific date time, use dateTime parameter.

    Properties:
        url: /challenge/v1/admin/namespaces/{namespace}/challenges/{challengeCode}/schedules

        method: GET

        tags: ["Schedules"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        challenge_code: (challengeCode) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

        date_time: (dateTime) OPTIONAL str in query

        limit: (limit) OPTIONAL int in query

        offset: (offset) OPTIONAL int in query

        user_id: (userId) OPTIONAL str in query

    Responses:
        200: OK - ModelListSchedulesResponse (OK)

        400: Bad Request - IamErrorResponse (20018: bad request: {{message}})

        401: Unauthorized - IamErrorResponse (20001: unauthorized access)

        403: Forbidden - IamErrorResponse (20013: insufficient permission)

        404: Not Found - ResponseError (20029: not found)

        500: Internal Server Error - ResponseError (20000: internal server error: {{message}})
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = AdminListSchedules.create(
        challenge_code=challenge_code,
        date_time=date_time,
        limit=limit,
        offset=offset,
        user_id=user_id,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminListSchedules)
async def admin_list_schedules_async(
    challenge_code: str,
    date_time: Optional[str] = None,
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    user_id: Optional[str] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get Challenge's schedules (adminListSchedules)

      * Required permission: ADMIN:NAMESPACE:{namespace}:CHALLENGE [READ]

    List schedules of given challenge for specific user. To query schedules prior to specific date time, use dateTime parameter.

    Properties:
        url: /challenge/v1/admin/namespaces/{namespace}/challenges/{challengeCode}/schedules

        method: GET

        tags: ["Schedules"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        challenge_code: (challengeCode) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

        date_time: (dateTime) OPTIONAL str in query

        limit: (limit) OPTIONAL int in query

        offset: (offset) OPTIONAL int in query

        user_id: (userId) OPTIONAL str in query

    Responses:
        200: OK - ModelListSchedulesResponse (OK)

        400: Bad Request - IamErrorResponse (20018: bad request: {{message}})

        401: Unauthorized - IamErrorResponse (20001: unauthorized access)

        403: Forbidden - IamErrorResponse (20013: insufficient permission)

        404: Not Found - ResponseError (20029: not found)

        500: Internal Server Error - ResponseError (20000: internal server error: {{message}})
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = AdminListSchedules.create(
        challenge_code=challenge_code,
        date_time=date_time,
        limit=limit,
        offset=offset,
        user_id=user_id,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(AdminListSchedulesByGoal)
def admin_list_schedules_by_goal(
    challenge_code: str,
    code: str,
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    user_id: Optional[str] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get goal's schedules (adminListSchedulesByGoal)

      * Required permission: ADMIN:NAMESPACE:{namespace}:CHALLENGE [READ]

    List schedules of given goal in a challenge for specific user.

    Properties:
        url: /challenge/v1/admin/namespaces/{namespace}/challenges/{challengeCode}/goals/{code}/schedules

        method: GET

        tags: ["Schedules"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        challenge_code: (challengeCode) REQUIRED str in path

        code: (code) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

        limit: (limit) OPTIONAL int in query

        offset: (offset) OPTIONAL int in query

        user_id: (userId) OPTIONAL str in query

    Responses:
        200: OK - ModelListScheduleByGoalResponse (OK)

        400: Bad Request - IamErrorResponse (20018: bad request: {{message}})

        401: Unauthorized - IamErrorResponse (20001: unauthorized access)

        403: Forbidden - IamErrorResponse (20013: insufficient permission)

        404: Not Found - ResponseError (20029: not found)

        500: Internal Server Error - ResponseError (20000: internal server error: {{message}})
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = AdminListSchedulesByGoal.create(
        challenge_code=challenge_code,
        code=code,
        limit=limit,
        offset=offset,
        user_id=user_id,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminListSchedulesByGoal)
async def admin_list_schedules_by_goal_async(
    challenge_code: str,
    code: str,
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    user_id: Optional[str] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get goal's schedules (adminListSchedulesByGoal)

      * Required permission: ADMIN:NAMESPACE:{namespace}:CHALLENGE [READ]

    List schedules of given goal in a challenge for specific user.

    Properties:
        url: /challenge/v1/admin/namespaces/{namespace}/challenges/{challengeCode}/goals/{code}/schedules

        method: GET

        tags: ["Schedules"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        challenge_code: (challengeCode) REQUIRED str in path

        code: (code) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

        limit: (limit) OPTIONAL int in query

        offset: (offset) OPTIONAL int in query

        user_id: (userId) OPTIONAL str in query

    Responses:
        200: OK - ModelListScheduleByGoalResponse (OK)

        400: Bad Request - IamErrorResponse (20018: bad request: {{message}})

        401: Unauthorized - IamErrorResponse (20001: unauthorized access)

        403: Forbidden - IamErrorResponse (20013: insufficient permission)

        404: Not Found - ResponseError (20029: not found)

        500: Internal Server Error - ResponseError (20000: internal server error: {{message}})
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = AdminListSchedulesByGoal.create(
        challenge_code=challenge_code,
        code=code,
        limit=limit,
        offset=offset,
        user_id=user_id,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(PublicListSchedules)
def public_list_schedules(
    challenge_code: str,
    date_time: Optional[str] = None,
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get Challenge's schedules (publicListSchedules)

      * Required permission: NAMESPACE:{namespace}:CHALLENGE [READ]

    List schedules of given challenge for specific user. To query schedules prior to specific date time, use dateTime parameter.

    Properties:
        url: /challenge/v1/public/namespaces/{namespace}/challenges/{challengeCode}/schedules

        method: GET

        tags: ["Schedules"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        challenge_code: (challengeCode) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

        date_time: (dateTime) OPTIONAL str in query

        limit: (limit) OPTIONAL int in query

        offset: (offset) OPTIONAL int in query

    Responses:
        200: OK - ModelListSchedulesResponse (OK)

        400: Bad Request - IamErrorResponse (20018: bad request: {{message}})

        401: Unauthorized - IamErrorResponse (20001: unauthorized access)

        403: Forbidden - IamErrorResponse (20013: insufficient permission)

        404: Not Found - ResponseError (20029: not found)

        500: Internal Server Error - ResponseError (20000: internal server error: {{message}})
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = PublicListSchedules.create(
        challenge_code=challenge_code,
        date_time=date_time,
        limit=limit,
        offset=offset,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(PublicListSchedules)
async def public_list_schedules_async(
    challenge_code: str,
    date_time: Optional[str] = None,
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get Challenge's schedules (publicListSchedules)

      * Required permission: NAMESPACE:{namespace}:CHALLENGE [READ]

    List schedules of given challenge for specific user. To query schedules prior to specific date time, use dateTime parameter.

    Properties:
        url: /challenge/v1/public/namespaces/{namespace}/challenges/{challengeCode}/schedules

        method: GET

        tags: ["Schedules"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        challenge_code: (challengeCode) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

        date_time: (dateTime) OPTIONAL str in query

        limit: (limit) OPTIONAL int in query

        offset: (offset) OPTIONAL int in query

    Responses:
        200: OK - ModelListSchedulesResponse (OK)

        400: Bad Request - IamErrorResponse (20018: bad request: {{message}})

        401: Unauthorized - IamErrorResponse (20001: unauthorized access)

        403: Forbidden - IamErrorResponse (20013: insufficient permission)

        404: Not Found - ResponseError (20029: not found)

        500: Internal Server Error - ResponseError (20000: internal server error: {{message}})
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = PublicListSchedules.create(
        challenge_code=challenge_code,
        date_time=date_time,
        limit=limit,
        offset=offset,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(PublicListSchedulesByGoal)
def public_list_schedules_by_goal(
    challenge_code: str,
    code: str,
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get goal's schedules (publicListSchedulesByGoal)

      * Required permission: NAMESPACE:{namespace}:CHALLENGE [READ]

    List schedules of given goal in a challenge for specific user.

    Properties:
        url: /challenge/v1/public/namespaces/{namespace}/challenges/{challengeCode}/goals/{code}/schedules

        method: GET

        tags: ["Schedules"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        challenge_code: (challengeCode) REQUIRED str in path

        code: (code) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

        limit: (limit) OPTIONAL int in query

        offset: (offset) OPTIONAL int in query

    Responses:
        200: OK - ModelListScheduleByGoalResponse (OK)

        400: Bad Request - IamErrorResponse (20018: bad request: {{message}})

        401: Unauthorized - IamErrorResponse (20001: unauthorized access)

        403: Forbidden - IamErrorResponse (20013: insufficient permission)

        404: Not Found - ResponseError (20029: not found)

        500: Internal Server Error - ResponseError (20000: internal server error: {{message}})
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = PublicListSchedulesByGoal.create(
        challenge_code=challenge_code,
        code=code,
        limit=limit,
        offset=offset,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(PublicListSchedulesByGoal)
async def public_list_schedules_by_goal_async(
    challenge_code: str,
    code: str,
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get goal's schedules (publicListSchedulesByGoal)

      * Required permission: NAMESPACE:{namespace}:CHALLENGE [READ]

    List schedules of given goal in a challenge for specific user.

    Properties:
        url: /challenge/v1/public/namespaces/{namespace}/challenges/{challengeCode}/goals/{code}/schedules

        method: GET

        tags: ["Schedules"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        challenge_code: (challengeCode) REQUIRED str in path

        code: (code) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

        limit: (limit) OPTIONAL int in query

        offset: (offset) OPTIONAL int in query

    Responses:
        200: OK - ModelListScheduleByGoalResponse (OK)

        400: Bad Request - IamErrorResponse (20018: bad request: {{message}})

        401: Unauthorized - IamErrorResponse (20001: unauthorized access)

        403: Forbidden - IamErrorResponse (20013: insufficient permission)

        404: Not Found - ResponseError (20029: not found)

        500: Internal Server Error - ResponseError (20000: internal server error: {{message}})
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = PublicListSchedulesByGoal.create(
        challenge_code=challenge_code,
        code=code,
        limit=limit,
        offset=offset,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

# AccelByte Gaming Services Iam Service

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from .....core import Operation
from .....core import HeaderStr
from .....core import HttpResponse

from ...models import OauthmodelErrorResponse
from ...models import OauthmodelTokenResponse


class PlatformTokenGrantV3(Operation):
    """OAuth2 access token generation specific to platform (PlatformTokenGrantV3)

    Platform token grant specifically used for performing token grant using platform, e.g. Steam, Device, etc.
    Automatically creates a headless account if the account associated with the platform does not exist yet, unless the createHeadless param is set to false.
    Requires all requests to have Authorization header set with Basic access authentication constructed from client id and client secret (only if using Confidential Client type). For more details on client types, refer to the [documentation guide](https://docs.accelbyte.io/gaming-services/modules/foundations/identity-access/authorization/manage-access-control-for-applications/#iam-client-types)

    ## Request Payload
    Device token grant should be requested along with device_id parameter.
    The other 3rd party platform token grant should be requested along with platform_token parameter.

    ## Supported platforms
    - **steam**: The platform_tokenâs value is the binary ticket returned by Steam.
    If this ticket was generated by Steam GetAuthTicketForWebApi with version >= 1.57, then platform token should use this style: `{identity}:{ticket}`, the `{identity}` was the parameter to call GetAuthTicketForWebApi when the ticket was created. Note: Do not contain `:` in this `{identity}`.
    - **steamopenid**: Steam's user authentication method using OpenID 2.0. The platform_token's value is URL generated by Steam on web authentication
    - **facebook**: The platform_tokenâs value is the authorization code returned by Facebook OAuth
    - **google**: The platform_tokenâs value is the authorization code or idToken returned by Google OAuth
    - **googleplaygames**: The platform_tokenâs value is the authorization code or idToken returned by Google play games OAuth
    - **oculus**: The platform_tokenâs value is a string composed of Oculus's user ID and the nonce separated by a colon (:).
    - **twitch**: The platform_tokenâs value is the authorization code returned by Twitch OAuth.
    - **discord**: The platform_tokenâs value is the authorization code returned by Discord OAuth
    - **android**: The device_id is the Androidâs device ID
    - **ios**: The device_id is the iOSâs device ID.
    - **apple**: The platform_tokenâs value is the authorization code or idToken returned by Apple OAuth.(We will use this code to generate APP token)
    - **device**: Every device that doesn't run Android and iOS is categorized as a device. The device_id is the deviceâs ID.
    - **justice**: The platform_tokenâs value is the designated userâs access token.
    - **epicgames**: The platform_tokenâs value is an access-token or authorization code obtained from Epicgames EOS Account Service.
    - **ps4**: The platform_tokenâs value is the authorization code returned by Sony OAuth.
    - **ps5**: The platform_tokenâs value is the authorization code returned by Sony OAuth.
    - **nintendo**: The platform_tokenâs value is the id_token returned by Nintendo OAuth.
    - **awscognito**: The platform_tokenâs value is the aws cognito access token or id token (JWT).
    - **live**: The platform_tokenâs value is xbox XSTS token
    - **xblweb**: The platform_tokenâs value is code returned by xbox after login
    - **netflix**: The platform_tokenâs value is GAT (Gamer Access Token) returned by Netflix backend
    - **snapchat**: The platform_tokenâs value is the authorization code returned by Snapchat OAuth.
    - **for specific generic oauth (OIDC)**: The platform_tokenâs value should be the same type as created OIDC auth type whether it is auth code, idToken or bearerToken.

    ## Account Group
    Several platforms are grouped under account groups. The accounts on these platforms have the same platform user id.
    Login using one of these platform will returns the same IAM user.
    Following is the current registered account grouping:
    - Steam group(steamnetwork):
    - steam
    - steamopenid
    - PSN group(psn)
    - ps4web
    - ps4
    - ps5
    - XBOX group(xbox)
    - live
    - xblweb
    - Oculus group(oculusgroup)
    - oculus
    - oculusweb

    ## Access Token Content
    Following is the access tokenâs content:
    - **namespace**. It is the namespace the token was generated from.
    - **display_name**. The display name of the sub. It is empty if the token is generated from the client credential
    - **roles** (deprecated). The subâs roles. It is empty if the token is generated from the client credential
    - **namespace_roles**. The subâs roles scoped to namespace. Improvement from roles, which make the role scoped to specific namespace instead of global to publisher namespace
    - **permissions**. The sub or audâ permissions
    - **bans**. The subâs list of bans. It is used by the IAM client for validating the token.
    - **jflgs**. It stands for Justice Flags. It is a special flag used for storing additional status information regarding the sub. It is implemented as a bit mask. Following explains what each bit represents:
    - 1: Email Address Verified
    - 2: Phone Number Verified
    - 4: Anonymous
    - 8: Suspicious Login
    - **aud**. The aud is the client ID.
    - **iat**. The time the token issues at. It is in Epoch time format
    - **exp**. The time the token expires. It is in Epoch time format
    - **sub**. The UserID. The sub is omitted if the token is generated from client credential

    ## Bans
    The JWT contains user's active bans with its expiry date. List of ban types can be obtained from /bans.

    ## 2FA remember device
    To remember device for 2FA, the request should provide cookie: device_token or header: Device-Token

    ## Login Queue
    When the Login Queue is enabled and at capacity, this API returns a 401 Unauthorized response, with the queue ticket included in the response body.

    ## Legal eligibility check
    If user hasn't accepted required legal policy (if any), the field `is_comply` will be false in response and response token will have no permission.

    Properties:
        url: /iam/v3/oauth/platforms/{platformId}/token

        method: POST

        tags: ["OAuth2.0"]

        consumes: ["application/x-www-form-urlencoded"]

        produces: ["application/json"]

        securities: [BASIC_AUTH]

        additional_data: (additionalData) OPTIONAL str in form_data

        client_id: (client_id) OPTIONAL str in form_data

        create_headless: (createHeadless) OPTIONAL bool in form_data

        device_id: (device_id) OPTIONAL str in form_data

        mac_address: (macAddress) OPTIONAL str in form_data

        platform_token: (platform_token) OPTIONAL str in form_data

        service_label: (serviceLabel) OPTIONAL float in form_data

        skip_set_cookie: (skipSetCookie) OPTIONAL bool in form_data

        platform_id: (platformId) REQUIRED str in path

    Responses:
        200: OK - OauthmodelTokenResponse (Token returned)

        400: Bad Request - OauthmodelErrorResponse (General request error)

        401: Unauthorized - OauthmodelErrorResponse (Client authentication failed)

        403: Forbidden - OauthmodelErrorResponse (Forbidden)

        503: Service Unavailable - OauthmodelErrorResponse (Third Party Server timeout or unavailable)
    """

    # region fields

    _url: str = "/iam/v3/oauth/platforms/{platformId}/token"
    _method: str = "POST"
    _consumes: List[str] = ["application/x-www-form-urlencoded"]
    _produces: List[str] = ["application/json"]
    _securities: List[List[str]] = [["BASIC_AUTH"]]
    _location_query: str = None

    additional_data: str  # OPTIONAL in [form_data]
    client_id: str  # OPTIONAL in [form_data]
    create_headless: bool  # OPTIONAL in [form_data]
    device_id: str  # OPTIONAL in [form_data]
    mac_address: str  # OPTIONAL in [form_data]
    platform_token: str  # OPTIONAL in [form_data]
    service_label: float  # OPTIONAL in [form_data]
    skip_set_cookie: bool  # OPTIONAL in [form_data]
    platform_id: str  # REQUIRED in [path]

    # endregion fields

    # region properties

    @property
    def url(self) -> str:
        return self._url

    @property
    def method(self) -> str:
        return self._method

    @property
    def consumes(self) -> List[str]:
        return self._consumes

    @property
    def produces(self) -> List[str]:
        return self._produces

    @property
    def securities(self) -> List[List[str]]:
        return self._securities

    @property
    def location_query(self) -> str:
        return self._location_query

    # endregion properties

    # region get methods

    # endregion get methods

    # region get_x_params methods

    def get_all_params(self) -> dict:
        return {
            "form_data": self.get_form_data_params(),
            "path": self.get_path_params(),
        }

    def get_form_data_params(self) -> dict:
        result = {}
        if hasattr(self, "additional_data"):
            result["additionalData"] = self.additional_data
        if hasattr(self, "client_id"):
            result["client_id"] = self.client_id
        if hasattr(self, "create_headless"):
            result["createHeadless"] = self.create_headless
        if hasattr(self, "device_id"):
            result["device_id"] = self.device_id
        if hasattr(self, "mac_address"):
            result["macAddress"] = self.mac_address
        if hasattr(self, "platform_token"):
            result["platform_token"] = self.platform_token
        if hasattr(self, "service_label"):
            result["serviceLabel"] = self.service_label
        if hasattr(self, "skip_set_cookie"):
            result["skipSetCookie"] = self.skip_set_cookie
        return result

    def get_path_params(self) -> dict:
        result = {}
        if hasattr(self, "platform_id"):
            result["platformId"] = self.platform_id
        return result

    # endregion get_x_params methods

    # region is/has methods

    # endregion is/has methods

    # region with_x methods

    def with_additional_data(self, value: str) -> PlatformTokenGrantV3:
        self.additional_data = value
        return self

    def with_client_id(self, value: str) -> PlatformTokenGrantV3:
        self.client_id = value
        return self

    def with_create_headless(self, value: bool) -> PlatformTokenGrantV3:
        self.create_headless = value
        return self

    def with_device_id(self, value: str) -> PlatformTokenGrantV3:
        self.device_id = value
        return self

    def with_mac_address(self, value: str) -> PlatformTokenGrantV3:
        self.mac_address = value
        return self

    def with_platform_token(self, value: str) -> PlatformTokenGrantV3:
        self.platform_token = value
        return self

    def with_service_label(self, value: float) -> PlatformTokenGrantV3:
        self.service_label = value
        return self

    def with_skip_set_cookie(self, value: bool) -> PlatformTokenGrantV3:
        self.skip_set_cookie = value
        return self

    def with_platform_id(self, value: str) -> PlatformTokenGrantV3:
        self.platform_id = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "additional_data") and self.additional_data:
            result["additionalData"] = str(self.additional_data)
        elif include_empty:
            result["additionalData"] = ""
        if hasattr(self, "client_id") and self.client_id:
            result["client_id"] = str(self.client_id)
        elif include_empty:
            result["client_id"] = ""
        if hasattr(self, "create_headless") and self.create_headless:
            result["createHeadless"] = bool(self.create_headless)
        elif include_empty:
            result["createHeadless"] = False
        if hasattr(self, "device_id") and self.device_id:
            result["device_id"] = str(self.device_id)
        elif include_empty:
            result["device_id"] = ""
        if hasattr(self, "mac_address") and self.mac_address:
            result["macAddress"] = str(self.mac_address)
        elif include_empty:
            result["macAddress"] = ""
        if hasattr(self, "platform_token") and self.platform_token:
            result["platform_token"] = str(self.platform_token)
        elif include_empty:
            result["platform_token"] = ""
        if hasattr(self, "service_label") and self.service_label:
            result["serviceLabel"] = float(self.service_label)
        elif include_empty:
            result["serviceLabel"] = 0.0
        if hasattr(self, "skip_set_cookie") and self.skip_set_cookie:
            result["skipSetCookie"] = bool(self.skip_set_cookie)
        elif include_empty:
            result["skipSetCookie"] = False
        if hasattr(self, "platform_id") and self.platform_id:
            result["platformId"] = str(self.platform_id)
        elif include_empty:
            result["platformId"] = ""
        return result

    # endregion to methods

    # region response methods

    # noinspection PyMethodMayBeStatic
    def parse_response(
        self, code: int, content_type: str, content: Any
    ) -> Tuple[
        Union[None, OauthmodelTokenResponse],
        Union[None, HttpResponse, OauthmodelErrorResponse],
    ]:
        """Parse the given response.

        200: OK - OauthmodelTokenResponse (Token returned)

        400: Bad Request - OauthmodelErrorResponse (General request error)

        401: Unauthorized - OauthmodelErrorResponse (Client authentication failed)

        403: Forbidden - OauthmodelErrorResponse (Forbidden)

        503: Service Unavailable - OauthmodelErrorResponse (Third Party Server timeout or unavailable)

        ---: HttpResponse (Undocumented Response)

        ---: HttpResponse (Unexpected Content-Type Error)

        ---: HttpResponse (Unhandled Error)
        """
        pre_processed_response, error = self.pre_process_response(
            code=code, content_type=content_type, content=content
        )
        if error is not None:
            return None, None if error.is_no_content() else error
        code, content_type, content = pre_processed_response

        if code == 200:
            return OauthmodelTokenResponse.create_from_dict(content), None
        if code == 400:
            return None, OauthmodelErrorResponse.create_from_dict(content)
        if code == 401:
            return None, OauthmodelErrorResponse.create_from_dict(content)
        if code == 403:
            return None, OauthmodelErrorResponse.create_from_dict(content)
        if code == 503:
            return None, OauthmodelErrorResponse.create_from_dict(content)

        return self.handle_undocumented_response(
            code=code, content_type=content_type, content=content
        )

    # endregion response methods

    # region static methods

    @classmethod
    def create(
        cls,
        platform_id: str,
        additional_data: Optional[str] = None,
        client_id: Optional[str] = None,
        create_headless: Optional[bool] = None,
        device_id: Optional[str] = None,
        mac_address: Optional[str] = None,
        platform_token: Optional[str] = None,
        service_label: Optional[float] = None,
        skip_set_cookie: Optional[bool] = None,
        **kwargs,
    ) -> PlatformTokenGrantV3:
        instance = cls()
        instance.platform_id = platform_id
        if additional_data is not None:
            instance.additional_data = additional_data
        if client_id is not None:
            instance.client_id = client_id
        if create_headless is not None:
            instance.create_headless = create_headless
        if device_id is not None:
            instance.device_id = device_id
        if mac_address is not None:
            instance.mac_address = mac_address
        if platform_token is not None:
            instance.platform_token = platform_token
        if service_label is not None:
            instance.service_label = service_label
        if skip_set_cookie is not None:
            instance.skip_set_cookie = skip_set_cookie
        if x_flight_id := kwargs.get("x_flight_id", None):
            instance.x_flight_id = x_flight_id
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> PlatformTokenGrantV3:
        instance = cls()
        if "additionalData" in dict_ and dict_["additionalData"] is not None:
            instance.additional_data = str(dict_["additionalData"])
        elif include_empty:
            instance.additional_data = ""
        if "client_id" in dict_ and dict_["client_id"] is not None:
            instance.client_id = str(dict_["client_id"])
        elif include_empty:
            instance.client_id = ""
        if "createHeadless" in dict_ and dict_["createHeadless"] is not None:
            instance.create_headless = bool(dict_["createHeadless"])
        elif include_empty:
            instance.create_headless = False
        if "device_id" in dict_ and dict_["device_id"] is not None:
            instance.device_id = str(dict_["device_id"])
        elif include_empty:
            instance.device_id = ""
        if "macAddress" in dict_ and dict_["macAddress"] is not None:
            instance.mac_address = str(dict_["macAddress"])
        elif include_empty:
            instance.mac_address = ""
        if "platform_token" in dict_ and dict_["platform_token"] is not None:
            instance.platform_token = str(dict_["platform_token"])
        elif include_empty:
            instance.platform_token = ""
        if "serviceLabel" in dict_ and dict_["serviceLabel"] is not None:
            instance.service_label = float(dict_["serviceLabel"])
        elif include_empty:
            instance.service_label = 0.0
        if "skipSetCookie" in dict_ and dict_["skipSetCookie"] is not None:
            instance.skip_set_cookie = bool(dict_["skipSetCookie"])
        elif include_empty:
            instance.skip_set_cookie = False
        if "platformId" in dict_ and dict_["platformId"] is not None:
            instance.platform_id = str(dict_["platformId"])
        elif include_empty:
            instance.platform_id = ""
        return instance

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "additionalData": "additional_data",
            "client_id": "client_id",
            "createHeadless": "create_headless",
            "device_id": "device_id",
            "macAddress": "mac_address",
            "platform_token": "platform_token",
            "serviceLabel": "service_label",
            "skipSetCookie": "skip_set_cookie",
            "platformId": "platform_id",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "additionalData": False,
            "client_id": False,
            "createHeadless": False,
            "device_id": False,
            "macAddress": False,
            "platform_token": False,
            "serviceLabel": False,
            "skipSetCookie": False,
            "platformId": True,
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

"""Auto-generated package that contains models used by the AccelByte Gaming Services Platform Service."""

__version__ = "6.14.0"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .delete_revocation_config import DeleteRevocationConfig
from .do_revocation import DoRevocation
from .get_revocation_config import GetRevocationConfig
from .query_revocation_histories import QueryRevocationHistories
from .query_revocation_histories import (
    SourceEnum as QueryRevocationHistoriesSourceEnum,
    StatusEnum as QueryRevocationHistoriesStatusEnum,
)
from .update_revocation_config import UpdateRevocationConfig



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import HeaderStr
from ....core import get_namespace as get_services_namespace
from ....core import run_request
from ....core import run_request_async
from ....core import same_doc_as

from ..models import ApimodelsConfigurationRequest
from ..models import ApimodelsConfigurationResponse
from ..models import ApimodelsQueueStatusResponse
from ..models import ResponseError

from ..operations.admin_v1 import AdminGetConfiguration
from ..operations.admin_v1 import AdminGetStatus
from ..operations.admin_v1 import AdminUpdateConfiguration


@same_doc_as(AdminGetConfiguration)
def admin_get_configuration(
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get Configuration (adminGetConfiguration)

    This API is used to get log queue configuration of a namespace.
    Calling this endpoint with namespace which has not set up configuration will return a valid configuration with default value

    Properties:
        url: /login-queue/v1/admin/namespaces/{namespace}/config

        method: GET

        tags: ["Admin V1"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ApimodelsConfigurationResponse (OK)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = AdminGetConfiguration.create(
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminGetConfiguration)
async def admin_get_configuration_async(
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get Configuration (adminGetConfiguration)

    This API is used to get log queue configuration of a namespace.
    Calling this endpoint with namespace which has not set up configuration will return a valid configuration with default value

    Properties:
        url: /login-queue/v1/admin/namespaces/{namespace}/config

        method: GET

        tags: ["Admin V1"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ApimodelsConfigurationResponse (OK)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = AdminGetConfiguration.create(
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(AdminGetStatus)
def admin_get_status(
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get login queue status (adminGetStatus)

    Get login queue status

    Properties:
        url: /login-queue/v1/admin/namespaces/{namespace}/status

        method: GET

        tags: ["Admin V1"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ApimodelsQueueStatusResponse (OK)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = AdminGetStatus.create(
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminGetStatus)
async def admin_get_status_async(
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get login queue status (adminGetStatus)

    Get login queue status

    Properties:
        url: /login-queue/v1/admin/namespaces/{namespace}/status

        method: GET

        tags: ["Admin V1"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ApimodelsQueueStatusResponse (OK)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = AdminGetStatus.create(
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(AdminUpdateConfiguration)
def admin_update_configuration(
    body: ApimodelsConfigurationRequest,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Update Configuration (adminUpdateConfiguration)

    This API is used to set/update log queue configuration of a namespace.
    This endpoint has upsert behavior. Calling the endpoint to a namespace with no configuration will make the service to create a new configuration.
    When creating new configuration, empty field will have default value:
    * enabled = false
    * maxConcurrency = 1000000
    * maxLoginRate = 500
    * safetyMarginPercentage = 5
    * minActivationPeriodInSecond = 600
    * playerReconnectGracePeriodInSecond = 300
    * queueReconnectGracePeriodInSecond = 60
    * playerPollingTimeInSecond = 20

    Calling this endpoint with namespace that has configuration will replace the old configuration.

    Input validation:
    * maxConcurrency must be > 0 and <= 10000000 (0 < x <= 10000000)
    * maxLoginRate must be > 0 and <= 100000 (0 < x <= 100000)
    * minActivationPeriodInSecond, playerReconnectGracePeriodInSecond, playerPollingTimeInSecond and queueReconnectGracePeriodInSecond must be > 0 and <= 21600 (0 < x <= 21600)
    * playerPollingTimeInSecond must be smaller than queueReconnectGracePeriodInSecond
    * safetyMarginPercentage must be >= 0 and < 100 (0 <= x < 100)

    Properties:
        url: /login-queue/v1/admin/namespaces/{namespace}/config

        method: PUT

        tags: ["Admin V1"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ApimodelsConfigurationRequest in body

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ApimodelsConfigurationResponse (OK)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = AdminUpdateConfiguration.create(
        body=body,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminUpdateConfiguration)
async def admin_update_configuration_async(
    body: ApimodelsConfigurationRequest,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Update Configuration (adminUpdateConfiguration)

    This API is used to set/update log queue configuration of a namespace.
    This endpoint has upsert behavior. Calling the endpoint to a namespace with no configuration will make the service to create a new configuration.
    When creating new configuration, empty field will have default value:
    * enabled = false
    * maxConcurrency = 1000000
    * maxLoginRate = 500
    * safetyMarginPercentage = 5
    * minActivationPeriodInSecond = 600
    * playerReconnectGracePeriodInSecond = 300
    * queueReconnectGracePeriodInSecond = 60
    * playerPollingTimeInSecond = 20

    Calling this endpoint with namespace that has configuration will replace the old configuration.

    Input validation:
    * maxConcurrency must be > 0 and <= 10000000 (0 < x <= 10000000)
    * maxLoginRate must be > 0 and <= 100000 (0 < x <= 100000)
    * minActivationPeriodInSecond, playerReconnectGracePeriodInSecond, playerPollingTimeInSecond and queueReconnectGracePeriodInSecond must be > 0 and <= 21600 (0 < x <= 21600)
    * playerPollingTimeInSecond must be smaller than queueReconnectGracePeriodInSecond
    * safetyMarginPercentage must be >= 0 and < 100 (0 <= x < 100)

    Properties:
        url: /login-queue/v1/admin/namespaces/{namespace}/config

        method: PUT

        tags: ["Admin V1"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ApimodelsConfigurationRequest in body

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ApimodelsConfigurationResponse (OK)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = AdminUpdateConfiguration.create(
        body=body,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import HeaderStr
from ....core import get_namespace as get_services_namespace
from ....core import run_request
from ....core import run_request_async
from ....core import deprecated
from ....core import same_doc_as

from ..models import ModelsPlatformCredentials
from ..models import ResponseError

from ..operations.certificate import AdminUploadXBoxCertificate


@deprecated
@same_doc_as(AdminUploadXBoxCertificate)
def admin_upload_x_box_certificate(
    certname: str,
    file: Any,
    password: str,
    description: Optional[str] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Upload certificates for XBox. (adminUploadXBoxCertificate)

    Upload certificates for XBox. Certificate must be in the valid form of PFX format. 'certname'' must be specified to 'xbl-pfx' for Session Sync to work

    Properties:
        url: /session/v1/admin/namespaces/{namespace}/certificates/pfx/platforms/xbl

        method: PUT

        tags: ["Certificate"]

        consumes: ["multipart/form-data"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        description: (description) OPTIONAL str in form_data

        certname: (certname) REQUIRED str in form_data

        file: (file) REQUIRED Any in form_data

        password: (password) REQUIRED str in form_data

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ModelsPlatformCredentials (OK)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)

        404: Not Found - ResponseError (Not Found)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = AdminUploadXBoxCertificate.create(
        certname=certname,
        file=file,
        password=password,
        description=description,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@deprecated
@same_doc_as(AdminUploadXBoxCertificate)
async def admin_upload_x_box_certificate_async(
    certname: str,
    file: Any,
    password: str,
    description: Optional[str] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Upload certificates for XBox. (adminUploadXBoxCertificate)

    Upload certificates for XBox. Certificate must be in the valid form of PFX format. 'certname'' must be specified to 'xbl-pfx' for Session Sync to work

    Properties:
        url: /session/v1/admin/namespaces/{namespace}/certificates/pfx/platforms/xbl

        method: PUT

        tags: ["Certificate"]

        consumes: ["multipart/form-data"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        description: (description) OPTIONAL str in form_data

        certname: (certname) REQUIRED str in form_data

        file: (file) REQUIRED Any in form_data

        password: (password) REQUIRED str in form_data

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ModelsPlatformCredentials (OK)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)

        404: Not Found - ResponseError (Not Found)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = AdminUploadXBoxCertificate.create(
        certname=certname,
        file=file,
        password=password,
        description=description,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import HeaderStr
from ....core import get_namespace as get_services_namespace
from ....core import run_request
from ....core import run_request_async
from ....core import deprecated
from ....core import same_doc_as

from ..models import AcceptAgreementRequest
from ..models import AcceptAgreementResponse
from ..models import ErrorEntity
from ..models import PagedRetrieveUserAcceptedAgreementResponse
from ..models import RetrieveAcceptedAgreementResponse

from ..operations.agreement import AcceptVersionedPolicy
from ..operations.agreement import BulkAcceptVersionedPolicy
from ..operations.agreement import ChangePreferenceConsent
from ..operations.agreement import IndirectBulkAcceptVersionedPolicyV2
from ..operations.agreement import OldRetrieveAcceptedAgreements
from ..operations.agreement import OldRetrieveAllUsersByPolicyVersion
from ..operations.agreement import PublicChangePreferenceConsent
from ..operations.agreement import PublicIndirectBulkAcceptVersionedPolicy
from ..operations.agreement import RetrieveAgreementsPublic


@same_doc_as(AcceptVersionedPolicy)
def accept_versioned_policy(
    localized_policy_version_id: str,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Accept a Policy Version (acceptVersionedPolicy)

    Accepts a legal policy version. Supply with localized version policy id to accept an agreement

    Properties:
        url: /agreement/public/agreements/localized-policy-versions/{localizedPolicyVersionId}

        method: POST

        tags: ["Agreement"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        localized_policy_version_id: (localizedPolicyVersionId) REQUIRED str in path

    Responses:
        201: Created - (successful anonymize)

        400: Bad Request - ErrorEntity (40045: errors.net.accelbyte.platform.legal.user_id_needed | 40035: errors.net.accelbyte.platform.legal.invalid_localize_policy_version_id)
    """
    request = AcceptVersionedPolicy.create(
        localized_policy_version_id=localized_policy_version_id,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AcceptVersionedPolicy)
async def accept_versioned_policy_async(
    localized_policy_version_id: str,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Accept a Policy Version (acceptVersionedPolicy)

    Accepts a legal policy version. Supply with localized version policy id to accept an agreement

    Properties:
        url: /agreement/public/agreements/localized-policy-versions/{localizedPolicyVersionId}

        method: POST

        tags: ["Agreement"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        localized_policy_version_id: (localizedPolicyVersionId) REQUIRED str in path

    Responses:
        201: Created - (successful anonymize)

        400: Bad Request - ErrorEntity (40045: errors.net.accelbyte.platform.legal.user_id_needed | 40035: errors.net.accelbyte.platform.legal.invalid_localize_policy_version_id)
    """
    request = AcceptVersionedPolicy.create(
        localized_policy_version_id=localized_policy_version_id,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(BulkAcceptVersionedPolicy)
def bulk_accept_versioned_policy(
    body: Optional[List[AcceptAgreementRequest]] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Bulk Accept Policy Versions (bulkAcceptVersionedPolicy)

    Accepts many legal policy versions all at once. Supply with localized version policy id to accept an agreement.

    Properties:
        url: /agreement/public/agreements/policies

        method: POST

        tags: ["Agreement"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) OPTIONAL List[AcceptAgreementRequest] in body

    Responses:
        201: Created - AcceptAgreementResponse (successful operation)

        400: Bad Request - ErrorEntity (40045: errors.net.accelbyte.platform.legal.user_id_needed | 40035: errors.net.accelbyte.platform.legal.invalid_localize_policy_version_id)
    """
    request = BulkAcceptVersionedPolicy.create(
        body=body,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(BulkAcceptVersionedPolicy)
async def bulk_accept_versioned_policy_async(
    body: Optional[List[AcceptAgreementRequest]] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Bulk Accept Policy Versions (bulkAcceptVersionedPolicy)

    Accepts many legal policy versions all at once. Supply with localized version policy id to accept an agreement.

    Properties:
        url: /agreement/public/agreements/policies

        method: POST

        tags: ["Agreement"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) OPTIONAL List[AcceptAgreementRequest] in body

    Responses:
        201: Created - AcceptAgreementResponse (successful operation)

        400: Bad Request - ErrorEntity (40045: errors.net.accelbyte.platform.legal.user_id_needed | 40035: errors.net.accelbyte.platform.legal.invalid_localize_policy_version_id)
    """
    request = BulkAcceptVersionedPolicy.create(
        body=body,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(ChangePreferenceConsent)
def change_preference_consent(
    user_id: str,
    body: Optional[List[AcceptAgreementRequest]] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Change Preference Consent (changePreferenceConsent)

    This API will Update Preference Consent

    Properties:
        url: /agreement/admin/agreements/localized-policy-versions/preferences/namespaces/{namespace}/userId/{userId}

        method: PATCH

        tags: ["Agreement"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) OPTIONAL List[AcceptAgreementRequest] in body

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

    Responses:
        200: OK - (operation successful)

        404: Not Found - ErrorEntity (40047: errors.net.accelbyte.platform.legal.user_agreement_not_found)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = ChangePreferenceConsent.create(
        user_id=user_id,
        body=body,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(ChangePreferenceConsent)
async def change_preference_consent_async(
    user_id: str,
    body: Optional[List[AcceptAgreementRequest]] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Change Preference Consent (changePreferenceConsent)

    This API will Update Preference Consent

    Properties:
        url: /agreement/admin/agreements/localized-policy-versions/preferences/namespaces/{namespace}/userId/{userId}

        method: PATCH

        tags: ["Agreement"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) OPTIONAL List[AcceptAgreementRequest] in body

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

    Responses:
        200: OK - (operation successful)

        404: Not Found - ErrorEntity (40047: errors.net.accelbyte.platform.legal.user_agreement_not_found)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = ChangePreferenceConsent.create(
        user_id=user_id,
        body=body,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@deprecated
@same_doc_as(IndirectBulkAcceptVersionedPolicyV2)
def indirect_bulk_accept_versioned_policy_v2(
    client_id: str,
    country_code: str,
    user_id: str,
    body: Optional[List[AcceptAgreementRequest]] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Bulk Accept Policy Versions (Indirect) (indirectBulkAcceptVersionedPolicyV2)

    Accepts many legal policy versions all at once. Supply with localized version policy id, version policy id, policy id, userId, namespace, country code and client id to accept an agreement. This endpoint used by APIGateway during new user registration.

    Properties:
        url: /agreement/public/agreements/policies/namespaces/{namespace}/countries/{countryCode}/clients/{clientId}/users/{userId}

        method: POST

        tags: ["Agreement"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) OPTIONAL List[AcceptAgreementRequest] in body

        client_id: (clientId) REQUIRED str in path

        country_code: (countryCode) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

    Responses:
        201: Created - AcceptAgreementResponse (successful operation)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = IndirectBulkAcceptVersionedPolicyV2.create(
        client_id=client_id,
        country_code=country_code,
        user_id=user_id,
        body=body,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@deprecated
@same_doc_as(IndirectBulkAcceptVersionedPolicyV2)
async def indirect_bulk_accept_versioned_policy_v2_async(
    client_id: str,
    country_code: str,
    user_id: str,
    body: Optional[List[AcceptAgreementRequest]] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Bulk Accept Policy Versions (Indirect) (indirectBulkAcceptVersionedPolicyV2)

    Accepts many legal policy versions all at once. Supply with localized version policy id, version policy id, policy id, userId, namespace, country code and client id to accept an agreement. This endpoint used by APIGateway during new user registration.

    Properties:
        url: /agreement/public/agreements/policies/namespaces/{namespace}/countries/{countryCode}/clients/{clientId}/users/{userId}

        method: POST

        tags: ["Agreement"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) OPTIONAL List[AcceptAgreementRequest] in body

        client_id: (clientId) REQUIRED str in path

        country_code: (countryCode) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

    Responses:
        201: Created - AcceptAgreementResponse (successful operation)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = IndirectBulkAcceptVersionedPolicyV2.create(
        client_id=client_id,
        country_code=country_code,
        user_id=user_id,
        body=body,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@deprecated
@same_doc_as(OldRetrieveAcceptedAgreements)
def old_retrieve_accepted_agreements(
    user_id: str, x_additional_headers: Optional[Dict[str, str]] = None, **kwargs
):
    """Retrieve Accepted Legal Agreements (oldRetrieveAcceptedAgreements)

    This API will return all accepted Legal Agreements for specified user

    Properties:
        url: /agreement/admin/agreements/policies/users/{userId}

        method: GET

        tags: ["Agreement"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        user_id: (userId) REQUIRED str in path

    Responses:
        200: OK - List[RetrieveAcceptedAgreementResponse] (successful operation)
    """
    request = OldRetrieveAcceptedAgreements.create(
        user_id=user_id,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@deprecated
@same_doc_as(OldRetrieveAcceptedAgreements)
async def old_retrieve_accepted_agreements_async(
    user_id: str, x_additional_headers: Optional[Dict[str, str]] = None, **kwargs
):
    """Retrieve Accepted Legal Agreements (oldRetrieveAcceptedAgreements)

    This API will return all accepted Legal Agreements for specified user

    Properties:
        url: /agreement/admin/agreements/policies/users/{userId}

        method: GET

        tags: ["Agreement"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        user_id: (userId) REQUIRED str in path

    Responses:
        200: OK - List[RetrieveAcceptedAgreementResponse] (successful operation)
    """
    request = OldRetrieveAcceptedAgreements.create(
        user_id=user_id,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@deprecated
@same_doc_as(OldRetrieveAllUsersByPolicyVersion)
def old_retrieve_all_users_by_policy_version(
    policy_version_id: str,
    keyword: Optional[str] = None,
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Retrieve Users Accepting Legal Agreements (oldRetrieveAllUsersByPolicyVersion)

    This API will return users who has accepted a specific policy version.

    Properties:
        url: /agreement/admin/agreements/policy-versions/users

        method: GET

        tags: ["Agreement"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        keyword: (keyword) OPTIONAL str in query

        limit: (limit) OPTIONAL int in query

        offset: (offset) OPTIONAL int in query

        policy_version_id: (policyVersionId) REQUIRED str in query

    Responses:
        200: OK - PagedRetrieveUserAcceptedAgreementResponse (successful operation)

        404: Not Found - ErrorEntity (40035: errors.net.accelbyte.platform.legal.policy_version_not_found)
    """
    request = OldRetrieveAllUsersByPolicyVersion.create(
        policy_version_id=policy_version_id,
        keyword=keyword,
        limit=limit,
        offset=offset,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@deprecated
@same_doc_as(OldRetrieveAllUsersByPolicyVersion)
async def old_retrieve_all_users_by_policy_version_async(
    policy_version_id: str,
    keyword: Optional[str] = None,
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Retrieve Users Accepting Legal Agreements (oldRetrieveAllUsersByPolicyVersion)

    This API will return users who has accepted a specific policy version.

    Properties:
        url: /agreement/admin/agreements/policy-versions/users

        method: GET

        tags: ["Agreement"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        keyword: (keyword) OPTIONAL str in query

        limit: (limit) OPTIONAL int in query

        offset: (offset) OPTIONAL int in query

        policy_version_id: (policyVersionId) REQUIRED str in query

    Responses:
        200: OK - PagedRetrieveUserAcceptedAgreementResponse (successful operation)

        404: Not Found - ErrorEntity (40035: errors.net.accelbyte.platform.legal.policy_version_not_found)
    """
    request = OldRetrieveAllUsersByPolicyVersion.create(
        policy_version_id=policy_version_id,
        keyword=keyword,
        limit=limit,
        offset=offset,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(PublicChangePreferenceConsent)
def public_change_preference_consent(
    body: Optional[List[AcceptAgreementRequest]] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Accept/Revoke Marketing Preference Consent (publicChangePreferenceConsent)

    Change marketing preference consent.

    Properties:
        url: /agreement/public/agreements/localized-policy-versions/preferences

        method: PATCH

        tags: ["Agreement"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) OPTIONAL List[AcceptAgreementRequest] in body

    Responses:
        200: OK - (Successful operation)

        400: Bad Request - ErrorEntity (40017: Policy with id : [{policyId}] is not marketing preference | 40045: errors.net.accelbyte.platform.legal.user_id_needed)
    """
    request = PublicChangePreferenceConsent.create(
        body=body,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(PublicChangePreferenceConsent)
async def public_change_preference_consent_async(
    body: Optional[List[AcceptAgreementRequest]] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Accept/Revoke Marketing Preference Consent (publicChangePreferenceConsent)

    Change marketing preference consent.

    Properties:
        url: /agreement/public/agreements/localized-policy-versions/preferences

        method: PATCH

        tags: ["Agreement"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) OPTIONAL List[AcceptAgreementRequest] in body

    Responses:
        200: OK - (Successful operation)

        400: Bad Request - ErrorEntity (40017: Policy with id : [{policyId}] is not marketing preference | 40045: errors.net.accelbyte.platform.legal.user_id_needed)
    """
    request = PublicChangePreferenceConsent.create(
        body=body,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@deprecated
@same_doc_as(PublicIndirectBulkAcceptVersionedPolicy)
def public_indirect_bulk_accept_versioned_policy(
    user_id: str,
    body: Optional[List[AcceptAgreementRequest]] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Bulk Accept Policy Versions (Indirect) (publicIndirectBulkAcceptVersionedPolicy)

    Accepts many legal policy versions all at once. Supply with localized version policy id and userId to accept an agreement. This endpoint used by Authentication Service during new user registration.

    Properties:
        url: /agreement/public/agreements/policies/users/{userId}

        method: POST

        tags: ["Agreement"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) OPTIONAL List[AcceptAgreementRequest] in body

        user_id: (userId) REQUIRED str in path

    Responses:
        201: Created - AcceptAgreementResponse (successful operation)

        404: Not Found - ErrorEntity (40035: errors.net.accelbyte.platform.legal.policy_version_not_found)
    """
    request = PublicIndirectBulkAcceptVersionedPolicy.create(
        user_id=user_id,
        body=body,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@deprecated
@same_doc_as(PublicIndirectBulkAcceptVersionedPolicy)
async def public_indirect_bulk_accept_versioned_policy_async(
    user_id: str,
    body: Optional[List[AcceptAgreementRequest]] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Bulk Accept Policy Versions (Indirect) (publicIndirectBulkAcceptVersionedPolicy)

    Accepts many legal policy versions all at once. Supply with localized version policy id and userId to accept an agreement. This endpoint used by Authentication Service during new user registration.

    Properties:
        url: /agreement/public/agreements/policies/users/{userId}

        method: POST

        tags: ["Agreement"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) OPTIONAL List[AcceptAgreementRequest] in body

        user_id: (userId) REQUIRED str in path

    Responses:
        201: Created - AcceptAgreementResponse (successful operation)

        404: Not Found - ErrorEntity (40035: errors.net.accelbyte.platform.legal.policy_version_not_found)
    """
    request = PublicIndirectBulkAcceptVersionedPolicy.create(
        user_id=user_id,
        body=body,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(RetrieveAgreementsPublic)
def retrieve_agreements_public(
    x_additional_headers: Optional[Dict[str, str]] = None, **kwargs
):
    """Retrieve the accepted Legal Agreements (retrieveAgreementsPublic)

    Retrieve accepted Legal Agreements.

    Properties:
        url: /agreement/public/agreements/policies

        method: GET

        tags: ["Agreement"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

    Responses:
        200: OK - List[RetrieveAcceptedAgreementResponse] (successful operation)

        400: Bad Request - ErrorEntity (40045: errors.net.accelbyte.platform.legal.user_id_needed)
    """
    request = RetrieveAgreementsPublic.create()
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(RetrieveAgreementsPublic)
async def retrieve_agreements_public_async(
    x_additional_headers: Optional[Dict[str, str]] = None, **kwargs
):
    """Retrieve the accepted Legal Agreements (retrieveAgreementsPublic)

    Retrieve accepted Legal Agreements.

    Properties:
        url: /agreement/public/agreements/policies

        method: GET

        tags: ["Agreement"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

    Responses:
        200: OK - List[RetrieveAcceptedAgreementResponse] (successful operation)

        400: Bad Request - ErrorEntity (40045: errors.net.accelbyte.platform.legal.user_id_needed)
    """
    request = RetrieveAgreementsPublic.create()
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# AccelByte Gaming Services Platform Service

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import Model
from ....core import StrEnum


class EnvEnum(StrEnum):
    LIVE = "LIVE"
    SANDBOX = "SANDBOX"


class ResetJobRequest(Model):
    """Reset job request (ResetJobRequest)

    Properties:
        env: (env) OPTIONAL Union[str, EnvEnum]

        last_time: (lastTime) OPTIONAL str
    """

    # region fields

    env: Union[str, EnvEnum]  # OPTIONAL
    last_time: str  # OPTIONAL

    # endregion fields

    # region with_x methods

    def with_env(self, value: Union[str, EnvEnum]) -> ResetJobRequest:
        self.env = value
        return self

    def with_last_time(self, value: str) -> ResetJobRequest:
        self.last_time = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "env"):
            result["env"] = str(self.env)
        elif include_empty:
            result["env"] = Union[str, EnvEnum]()
        if hasattr(self, "last_time"):
            result["lastTime"] = str(self.last_time)
        elif include_empty:
            result["lastTime"] = ""
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls,
        env: Optional[Union[str, EnvEnum]] = None,
        last_time: Optional[str] = None,
        **kwargs,
    ) -> ResetJobRequest:
        instance = cls()
        if env is not None:
            instance.env = env
        if last_time is not None:
            instance.last_time = last_time
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> ResetJobRequest:
        instance = cls()
        if not dict_:
            return instance
        if "env" in dict_ and dict_["env"] is not None:
            instance.env = str(dict_["env"])
        elif include_empty:
            instance.env = Union[str, EnvEnum]()
        if "lastTime" in dict_ and dict_["lastTime"] is not None:
            instance.last_time = str(dict_["lastTime"])
        elif include_empty:
            instance.last_time = ""
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, ResetJobRequest]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[ResetJobRequest]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[ResetJobRequest, List[ResetJobRequest], Dict[Any, ResetJobRequest]]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "env": "env",
            "lastTime": "last_time",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "env": False,
            "lastTime": False,
        }

    @staticmethod
    def get_enum_map() -> Dict[str, List[Any]]:
        return {
            "env": ["LIVE", "SANDBOX"],
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import HeaderStr
from ....core import get_namespace as get_services_namespace
from ....core import run_request
from ....core import run_request_async
from ....core import same_doc_as

from ..models import RetrieveSimplePolicyPublicResponseV2

from ..operations.policies_with_namespace_v2 import (
    RetrieveLatestPoliciesByNamespaceAndCountryPublic,
)


@same_doc_as(RetrieveLatestPoliciesByNamespaceAndCountryPublic)
def retrieve_latest_policies_by_namespace_and_country_public(
    client_id: str,
    country_code: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Retrieve Latest Policies by Namespace and Country (retrieveLatestPoliciesByNamespaceAndCountryPublic)

    This API is used to list all the related doc in register page, include optional & mandatory (when env config APP_LEGAL_AGREEMENT_ALWAYS_INCLUDE_DEFAULT=true).
    Other detail info:

    Here are the result of different cases
        * Document 1, Region US (default, mandatory), UA (optional); clientID: [client_A]
        * Document 2, Region US (default, optional), UA (mandatory); clientID: [client_A]
        * Document 3, Region UA (default, mandatory); clientID: [client_A]
        * Document 4, Region US (default, optional); clientID: [client_A]
        * Document 5, Region US (default, optional); clientID: [client_B]
        * Document 6, Region CA (mandatory, optional), UA (optional); clientID: [client_B]
        * Query by: Region UA + client_A
        * Response: Document 1 (UA, optional), Document 2 (UA, mandatory), Document 3 (UA, mandatory), Document 4 (US, optional)
        * Query by: Region CA + client_A
        * Response: Document 1 (US, mandatory), Document 2 (US, mandatory), Document 3 (UA, mandatory), Document 4 (US, optional)
        * Query by: Region UA + client_B
        * Response: Document 5 (US, optional), Document 6 (UA, optional)
        * Query by: Region CN + client_B
        * Response: Document 5 (US, optional), Document 6 (CA, mandatory)
    Note: If APP_LEGAL_AGREEMENT_ALWAYS_INCLUDE_DEFAULT=false the behavior will be same with `/agreement/public/policies/namespaces/{namespace}/countries/{country_code}?defaultOnEmpty=true&visibleOnly;=true`;Here are the result of different cases
        * Query by: Region UA + client_A
        * Response: Document 1 (UA, optional), Document 2 (UA, mandatory), Document 3 (UA, mandatory)
        * Query by: Region UA + client_B
        * Response: Document 5 (US, optional)

    Properties:
        url: /agreement/v2/public/policies/namespaces/{namespace}/countries/{countryCode}

        method: GET

        tags: ["Policies With Namespace V2"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        country_code: (countryCode) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

        client_id: (clientId) REQUIRED str in query

    Responses:
        200: OK - List[RetrieveSimplePolicyPublicResponseV2] (successful operation)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = RetrieveLatestPoliciesByNamespaceAndCountryPublic.create(
        client_id=client_id,
        country_code=country_code,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(RetrieveLatestPoliciesByNamespaceAndCountryPublic)
async def retrieve_latest_policies_by_namespace_and_country_public_async(
    client_id: str,
    country_code: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Retrieve Latest Policies by Namespace and Country (retrieveLatestPoliciesByNamespaceAndCountryPublic)

    This API is used to list all the related doc in register page, include optional & mandatory (when env config APP_LEGAL_AGREEMENT_ALWAYS_INCLUDE_DEFAULT=true).
    Other detail info:

    Here are the result of different cases
        * Document 1, Region US (default, mandatory), UA (optional); clientID: [client_A]
        * Document 2, Region US (default, optional), UA (mandatory); clientID: [client_A]
        * Document 3, Region UA (default, mandatory); clientID: [client_A]
        * Document 4, Region US (default, optional); clientID: [client_A]
        * Document 5, Region US (default, optional); clientID: [client_B]
        * Document 6, Region CA (mandatory, optional), UA (optional); clientID: [client_B]
        * Query by: Region UA + client_A
        * Response: Document 1 (UA, optional), Document 2 (UA, mandatory), Document 3 (UA, mandatory), Document 4 (US, optional)
        * Query by: Region CA + client_A
        * Response: Document 1 (US, mandatory), Document 2 (US, mandatory), Document 3 (UA, mandatory), Document 4 (US, optional)
        * Query by: Region UA + client_B
        * Response: Document 5 (US, optional), Document 6 (UA, optional)
        * Query by: Region CN + client_B
        * Response: Document 5 (US, optional), Document 6 (CA, mandatory)
    Note: If APP_LEGAL_AGREEMENT_ALWAYS_INCLUDE_DEFAULT=false the behavior will be same with `/agreement/public/policies/namespaces/{namespace}/countries/{country_code}?defaultOnEmpty=true&visibleOnly;=true`;Here are the result of different cases
        * Query by: Region UA + client_A
        * Response: Document 1 (UA, optional), Document 2 (UA, mandatory), Document 3 (UA, mandatory)
        * Query by: Region UA + client_B
        * Response: Document 5 (US, optional)

    Properties:
        url: /agreement/v2/public/policies/namespaces/{namespace}/countries/{countryCode}

        method: GET

        tags: ["Policies With Namespace V2"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        country_code: (countryCode) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

        client_id: (clientId) REQUIRED str in query

    Responses:
        200: OK - List[RetrieveSimplePolicyPublicResponseV2] (successful operation)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = RetrieveLatestPoliciesByNamespaceAndCountryPublic.create(
        client_id=client_id,
        country_code=country_code,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )



# Copyright (c) 2025 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.

from typing import Dict, Optional

from ...core import (
    SDK,
    AccelByteSDK,
)

from ...api import iam

from ._login_const import (
    DEFAULT_REFRESH_RATE,
    LOGIN_TYPE_PLATFORM,
)

from ._login_refresh import (
    try_refresh_login_internal,
    try_refresh_login_async_internal,
)


def login_platform_internal(
    platform_id: str,
    platform_token: str,
    refresh_if_possible: bool = False,
    refresh_rate: float = DEFAULT_REFRESH_RATE,
    x_additional_headers: Optional[Dict[str, str]] = None,
    sdk: Optional[AccelByteSDK] = None,
    **kwargs,
):
    sdk = sdk or SDK

    token: Optional[str] = None
    if refresh_if_possible:
        token = try_refresh_login_internal(
            refresh_rate=refresh_rate,
            x_additional_headers=x_additional_headers,
            sdk=sdk,
            **kwargs,
        )

    if not token:
        token, error = iam.platform_token_grant_v3(
            platform_id=platform_id,
            platform_token=platform_token,
            x_additional_headers=x_additional_headers,
            sdk=sdk,
            **kwargs,
        )
        if error:
            return None, error

    assert token, "Token value missing!"

    _, error = sdk.set_token(token=token, type=LOGIN_TYPE_PLATFORM)
    if error:
        return None, error

    return token, None


async def login_platform_async_internal(
    platform_id: str,
    platform_token: str,
    refresh_if_possible: bool = False,
    refresh_rate: float = DEFAULT_REFRESH_RATE,
    x_additional_headers: Optional[Dict[str, str]] = None,
    sdk: Optional[AccelByteSDK] = None,
    **kwargs,
):
    sdk = sdk or SDK

    token: Optional[str] = None
    if refresh_if_possible:
        token = await try_refresh_login_async_internal(
            refresh_rate=refresh_rate,
            x_additional_headers=x_additional_headers,
            sdk=sdk,
            **kwargs,
        )

    if not token:
        token, error = await iam.platform_token_grant_v3_async(
            platform_id=platform_id,
            platform_token=platform_token,
            x_additional_headers=x_additional_headers,
            sdk=sdk,
            **kwargs,
        )
        if error:
            return None, error

    assert token, "Token value missing!"

    _, error = sdk.set_token(token=token, type=LOGIN_TYPE_PLATFORM)
    if error:
        return None, error

    return token, None


__all__ = [
    "login_platform_internal",
    "login_platform_async_internal",
]



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# Custom Service Manager

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import Model


class SqlresourceSQLResourceConfiguration(Model):
    """Sqlresource SQL resource configuration (sqlresource.SQLResourceConfiguration)

    Properties:
        max_acu: (maxACU) REQUIRED float

        min_acu: (minACU) REQUIRED float

        multi_az: (multiAZ) REQUIRED bool

        profile_name: (profileName) OPTIONAL str
    """

    # region fields

    max_acu: float  # REQUIRED
    min_acu: float  # REQUIRED
    multi_az: bool  # REQUIRED
    profile_name: str  # OPTIONAL

    # endregion fields

    # region with_x methods

    def with_max_acu(self, value: float) -> SqlresourceSQLResourceConfiguration:
        self.max_acu = value
        return self

    def with_min_acu(self, value: float) -> SqlresourceSQLResourceConfiguration:
        self.min_acu = value
        return self

    def with_multi_az(self, value: bool) -> SqlresourceSQLResourceConfiguration:
        self.multi_az = value
        return self

    def with_profile_name(self, value: str) -> SqlresourceSQLResourceConfiguration:
        self.profile_name = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "max_acu"):
            result["maxACU"] = float(self.max_acu)
        elif include_empty:
            result["maxACU"] = 0.0
        if hasattr(self, "min_acu"):
            result["minACU"] = float(self.min_acu)
        elif include_empty:
            result["minACU"] = 0.0
        if hasattr(self, "multi_az"):
            result["multiAZ"] = bool(self.multi_az)
        elif include_empty:
            result["multiAZ"] = False
        if hasattr(self, "profile_name"):
            result["profileName"] = str(self.profile_name)
        elif include_empty:
            result["profileName"] = ""
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls,
        max_acu: float,
        min_acu: float,
        multi_az: bool,
        profile_name: Optional[str] = None,
        **kwargs,
    ) -> SqlresourceSQLResourceConfiguration:
        instance = cls()
        instance.max_acu = max_acu
        instance.min_acu = min_acu
        instance.multi_az = multi_az
        if profile_name is not None:
            instance.profile_name = profile_name
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> SqlresourceSQLResourceConfiguration:
        instance = cls()
        if not dict_:
            return instance
        if "maxACU" in dict_ and dict_["maxACU"] is not None:
            instance.max_acu = float(dict_["maxACU"])
        elif include_empty:
            instance.max_acu = 0.0
        if "minACU" in dict_ and dict_["minACU"] is not None:
            instance.min_acu = float(dict_["minACU"])
        elif include_empty:
            instance.min_acu = 0.0
        if "multiAZ" in dict_ and dict_["multiAZ"] is not None:
            instance.multi_az = bool(dict_["multiAZ"])
        elif include_empty:
            instance.multi_az = False
        if "profileName" in dict_ and dict_["profileName"] is not None:
            instance.profile_name = str(dict_["profileName"])
        elif include_empty:
            instance.profile_name = ""
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, SqlresourceSQLResourceConfiguration]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[SqlresourceSQLResourceConfiguration]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[
        SqlresourceSQLResourceConfiguration,
        List[SqlresourceSQLResourceConfiguration],
        Dict[Any, SqlresourceSQLResourceConfiguration],
    ]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "maxACU": "max_acu",
            "minACU": "min_acu",
            "multiAZ": "multi_az",
            "profileName": "profile_name",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "maxACU": True,
            "minACU": True,
            "multiAZ": True,
            "profileName": False,
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

"""Auto-generated package that contains models used by the Custom Service Manager."""

__version__ = "1.34.0"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from ._app import create_app_v1
from ._app import create_app_v1_async
from ._app import delete_app_v1
from ._app import delete_app_v1_async
from ._app import get_app_list_v1
from ._app import get_app_list_v1_async
from ._app import get_app_release_v1
from ._app import get_app_release_v1_async
from ._app import get_app_v1
from ._app import get_app_v1_async
from ._app import start_app_v1
from ._app import start_app_v1_async
from ._app import stop_app_v1
from ._app import stop_app_v1_async
from ._app import update_app_v1
from ._app import update_app_v1_async

from ._app_status_progress_v4 import get_app_status_progress_v4
from ._app_status_progress_v4 import get_app_status_progress_v4_async

from ._app_ui import create_app_ui
from ._app_ui import create_app_ui_async
from ._app_ui import delete_app_ui
from ._app_ui import delete_app_ui_async
from ._app_ui import list_app_ui
from ._app_ui import list_app_ui_async
from ._app_ui import upload_app_ui_file
from ._app_ui import upload_app_ui_file_async

from ._app_v2 import apply_app_config_v2
from ._app_v2 import apply_app_config_v2_async
from ._app_v2 import create_app_v2
from ._app_v2 import create_app_v2_async
from ._app_v2 import delete_app_v2
from ._app_v2 import delete_app_v2_async
from ._app_v2 import get_app_list_v2
from ._app_v2 import get_app_list_v2_async
from ._app_v2 import get_app_v2
from ._app_v2 import get_app_v2_async
from ._app_v2 import start_app_v2
from ._app_v2 import start_app_v2_async
from ._app_v2 import stop_app_v2
from ._app_v2 import stop_app_v2_async
from ._app_v2 import update_app_resources_resource_limit_form_v2
from ._app_v2 import update_app_resources_resource_limit_form_v2_async
from ._app_v2 import update_app_resources_v2
from ._app_v2 import update_app_resources_v2_async
from ._app_v2 import update_app_v2
from ._app_v2 import update_app_v2_async

from ._app_v4 import get_app_debug_info_v4
from ._app_v4 import get_app_debug_info_v4_async
from ._app_v4 import update_app_debug_mode_v4
from ._app_v4 import update_app_debug_mode_v4_async

from ._app_v5 import create_app_v5
from ._app_v5 import create_app_v5_async

from ._async_messaging import create_subscription_handler
from ._async_messaging import create_subscription_handler_async
from ._async_messaging import create_topic_handler
from ._async_messaging import create_topic_handler_async
from ._async_messaging import delete_topic_handler
from ._async_messaging import delete_topic_handler_async
from ._async_messaging import list_topics_handler
from ._async_messaging import list_topics_handler_async
from ._async_messaging import unsubscribe_topic_handler
from ._async_messaging import unsubscribe_topic_handler_async

from ._configuration import delete_secret_v1
from ._configuration import delete_secret_v1_async
from ._configuration import delete_variable_v1
from ._configuration import delete_variable_v1_async
from ._configuration import get_list_of_secrets_v1
from ._configuration import get_list_of_secrets_v1_async
from ._configuration import get_list_of_variables_v1
from ._configuration import get_list_of_variables_v1_async
from ._configuration import save_secret_v1
from ._configuration import save_secret_v1_async
from ._configuration import save_variable_v1
from ._configuration import save_variable_v1_async
from ._configuration import update_secret_v1
from ._configuration import update_secret_v1_async
from ._configuration import update_variable_v1
from ._configuration import update_variable_v1_async

from ._configuration_v2 import delete_secret_v2
from ._configuration_v2 import delete_secret_v2_async
from ._configuration_v2 import delete_variable_v2
from ._configuration_v2 import delete_variable_v2_async
from ._configuration_v2 import get_list_of_secrets_v2
from ._configuration_v2 import get_list_of_secrets_v2_async
from ._configuration_v2 import get_list_of_variables_v2
from ._configuration_v2 import get_list_of_variables_v2_async
from ._configuration_v2 import save_secret_v2
from ._configuration_v2 import save_secret_v2_async
from ._configuration_v2 import save_variable_v2
from ._configuration_v2 import save_variable_v2_async
from ._configuration_v2 import update_secret_v2
from ._configuration_v2 import update_secret_v2_async
from ._configuration_v2 import update_variable_v2
from ._configuration_v2 import update_variable_v2_async

from ._deployment import create_deployment_v1
from ._deployment import create_deployment_v1_async
from ._deployment import delete_deployment_v1
from ._deployment import delete_deployment_v1_async
from ._deployment import get_deployment_v1
from ._deployment import get_deployment_v1_async
from ._deployment import get_list_of_deployment_v1
from ._deployment import get_list_of_deployment_v1_async

from ._deployment_v2 import create_deployment_v2
from ._deployment_v2 import create_deployment_v2_async
from ._deployment_v2 import delete_deployment_v2
from ._deployment_v2 import delete_deployment_v2_async
from ._deployment_v2 import get_deployment_v2
from ._deployment_v2 import get_deployment_v2_async
from ._deployment_v2 import get_list_of_deployment_v2
from ._deployment_v2 import get_list_of_deployment_v2_async

from ._extend_files import get_extend_file
from ._extend_files import get_extend_file_async

from ._image import delete_app_images_v1
from ._image import delete_app_images_v1_async
from ._image import get_app_image_list_v1
from ._image import get_app_image_list_v1_async

from ._image_v2 import delete_app_images_v2
from ._image_v2 import delete_app_images_v2_async
from ._image_v2 import get_app_image_list_v2
from ._image_v2 import get_app_image_list_v2_async

from ._managed_resources import create_new_no_sql_database_credential_v2
from ._managed_resources import create_new_no_sql_database_credential_v2_async
from ._managed_resources import create_no_sql_cluster_v2
from ._managed_resources import create_no_sql_cluster_v2_async
from ._managed_resources import create_no_sql_database_credential_v2
from ._managed_resources import create_no_sql_database_credential_v2_async
from ._managed_resources import create_no_sql_database_v2
from ._managed_resources import create_no_sql_database_v2_async
from ._managed_resources import delete_no_sql_cluster_v2
from ._managed_resources import delete_no_sql_cluster_v2_async
from ._managed_resources import delete_no_sql_database_v2
from ._managed_resources import delete_no_sql_database_v2_async
from ._managed_resources import get_no_sql_access_tunnel_v2
from ._managed_resources import get_no_sql_access_tunnel_v2_async
from ._managed_resources import get_no_sql_app_list_v2
from ._managed_resources import get_no_sql_app_list_v2_async
from ._managed_resources import get_no_sql_cluster_v2
from ._managed_resources import get_no_sql_cluster_v2_async
from ._managed_resources import get_no_sql_database_v2
from ._managed_resources import get_no_sql_database_v2_async
from ._managed_resources import start_no_sql_cluster_v2
from ._managed_resources import start_no_sql_cluster_v2_async
from ._managed_resources import stop_no_sql_cluster_v2
from ._managed_resources import stop_no_sql_cluster_v2_async
from ._managed_resources import update_no_sql_cluster_v2
from ._managed_resources import update_no_sql_cluster_v2_async

from ._managed_resources_key_value import create_key_value_cluster_v2
from ._managed_resources_key_value import create_key_value_cluster_v2_async
from ._managed_resources_key_value import create_key_value_credential_v2
from ._managed_resources_key_value import create_key_value_credential_v2_async
from ._managed_resources_key_value import delete_key_value_cluster_v2
from ._managed_resources_key_value import delete_key_value_cluster_v2_async
from ._managed_resources_key_value import get_integration_app_key_value_cluster_v2
from ._managed_resources_key_value import get_integration_app_key_value_cluster_v2_async
from ._managed_resources_key_value import get_key_value_cluster_limit_config_v2
from ._managed_resources_key_value import get_key_value_cluster_limit_config_v2_async
from ._managed_resources_key_value import get_key_value_cluster_v2
from ._managed_resources_key_value import get_key_value_cluster_v2_async
from ._managed_resources_key_value import get_list_integrated_app_key_value_cluster_v2
from ._managed_resources_key_value import (
    get_list_integrated_app_key_value_cluster_v2_async,
)
from ._managed_resources_key_value import integrate_app_key_value_cluster_v2
from ._managed_resources_key_value import integrate_app_key_value_cluster_v2_async
from ._managed_resources_key_value import list_key_value_cluster_v2
from ._managed_resources_key_value import list_key_value_cluster_v2_async
from ._managed_resources_key_value import remove_integration_app_key_value_cluster_v2
from ._managed_resources_key_value import (
    remove_integration_app_key_value_cluster_v2_async,
)
from ._managed_resources_key_value import update_key_value_cluster_v2
from ._managed_resources_key_value import update_key_value_cluster_v2_async

from ._managed_resources_sql import create_sql_cluster_v2
from ._managed_resources_sql import create_sql_cluster_v2_async
from ._managed_resources_sql import create_sql_database_credential_v2
from ._managed_resources_sql import create_sql_database_credential_v2_async
from ._managed_resources_sql import create_sql_database_v2
from ._managed_resources_sql import create_sql_database_v2_async
from ._managed_resources_sql import delete_sql_cluster_v2
from ._managed_resources_sql import delete_sql_cluster_v2_async
from ._managed_resources_sql import delete_sql_database_v2
from ._managed_resources_sql import delete_sql_database_v2_async
from ._managed_resources_sql import get_sql_app_list_v2
from ._managed_resources_sql import get_sql_app_list_v2_async
from ._managed_resources_sql import get_sql_cluster_v2
from ._managed_resources_sql import get_sql_cluster_v2_async
from ._managed_resources_sql import get_sql_database_v2
from ._managed_resources_sql import get_sql_database_v2_async
from ._managed_resources_sql import start_sql_cluster_v2
from ._managed_resources_sql import start_sql_cluster_v2_async
from ._managed_resources_sql import stop_sql_cluster_v2
from ._managed_resources_sql import stop_sql_cluster_v2_async
from ._managed_resources_sql import update_sql_cluster_v2
from ._managed_resources_sql import update_sql_cluster_v2_async

from ._messages import public_get_messages
from ._messages import public_get_messages_async

from ._notification_subscription import bulk_save_subscription_app_notification_v2
from ._notification_subscription import bulk_save_subscription_app_notification_v2_async
from ._notification_subscription import (
    delete_subscription_app_notification_by_user_idv2,
)
from ._notification_subscription import (
    delete_subscription_app_notification_by_user_idv2_async,
)
from ._notification_subscription import delete_subscription_app_notification_v2
from ._notification_subscription import delete_subscription_app_notification_v2_async
from ._notification_subscription import get_notification_subscriber_list_v2
from ._notification_subscription import get_notification_subscriber_list_v2_async
from ._notification_subscription import get_subscription_v2_handler
from ._notification_subscription import get_subscription_v2_handler_async
from ._notification_subscription import subscribe_app_notification_v2
from ._notification_subscription import subscribe_app_notification_v2_async
from ._notification_subscription import subscribe_v2_handler
from ._notification_subscription import subscribe_v2_handler_async
from ._notification_subscription import unsubscribe_v2_handler
from ._notification_subscription import unsubscribe_v2_handler_async

from ._notification_subscription_v3 import delete_subscription_app_notification_v3
from ._notification_subscription_v3 import delete_subscription_app_notification_v3_async
from ._notification_subscription_v3 import get_notification_subscriber_list_v3
from ._notification_subscription_v3 import get_notification_subscriber_list_v3_async

from ._resources_limits import get_resources_limits
from ._resources_limits import get_resources_limits_async



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# Custom Service Manager

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import Model

from ..models.model_app_redeployment_detail import ModelAppRedeploymentDetail


class ModelAppRedeploymentInfo(Model):
    """Model app redeployment info (model.AppRedeploymentInfo)

    Properties:
        should_redeploy: (shouldRedeploy) REQUIRED bool

        details: (details) OPTIONAL List[ModelAppRedeploymentDetail]
    """

    # region fields

    should_redeploy: bool  # REQUIRED
    details: List[ModelAppRedeploymentDetail]  # OPTIONAL

    # endregion fields

    # region with_x methods

    def with_should_redeploy(self, value: bool) -> ModelAppRedeploymentInfo:
        self.should_redeploy = value
        return self

    def with_details(
        self, value: List[ModelAppRedeploymentDetail]
    ) -> ModelAppRedeploymentInfo:
        self.details = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "should_redeploy"):
            result["shouldRedeploy"] = bool(self.should_redeploy)
        elif include_empty:
            result["shouldRedeploy"] = False
        if hasattr(self, "details"):
            result["details"] = [
                i0.to_dict(include_empty=include_empty) for i0 in self.details
            ]
        elif include_empty:
            result["details"] = []
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls,
        should_redeploy: bool,
        details: Optional[List[ModelAppRedeploymentDetail]] = None,
        **kwargs,
    ) -> ModelAppRedeploymentInfo:
        instance = cls()
        instance.should_redeploy = should_redeploy
        if details is not None:
            instance.details = details
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> ModelAppRedeploymentInfo:
        instance = cls()
        if not dict_:
            return instance
        if "shouldRedeploy" in dict_ and dict_["shouldRedeploy"] is not None:
            instance.should_redeploy = bool(dict_["shouldRedeploy"])
        elif include_empty:
            instance.should_redeploy = False
        if "details" in dict_ and dict_["details"] is not None:
            instance.details = [
                ModelAppRedeploymentDetail.create_from_dict(
                    i0, include_empty=include_empty
                )
                for i0 in dict_["details"]
            ]
        elif include_empty:
            instance.details = []
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, ModelAppRedeploymentInfo]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[ModelAppRedeploymentInfo]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[
        ModelAppRedeploymentInfo,
        List[ModelAppRedeploymentInfo],
        Dict[Any, ModelAppRedeploymentInfo],
    ]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "shouldRedeploy": "should_redeploy",
            "details": "details",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "shouldRedeploy": True,
            "details": False,
        }

    # endregion static methods
